define(['testsuite/qunit', 'jquery', 'ep/color'], function (QUnit, $, ep) {

	QUnit.module("ep/color");
	
	QUnit.asyncTest("ep.color", function() {

		QUnit.equal(
			ep.color.rgbToHex({r:255,g:125,b:44}),
			"ff7d2c",
			"ep.color.rgbToHex({r:255,g:125,b:44})"
		);
		QUnit.equal(
			ep.color.rgbToHex({r:99,g:33,b:66}),
			"632142",
			"ep.color.rgbToHex({r:99,g:33,b:66})"
		);

		QUnit.deepEqual(
			ep.color.rgbToHsb({r:255,g:125,b:44}),
			{h:23,s:83,b:100},
			"ep.color.rgbToHsb({r:255,g:125,b:44})"
		);
		QUnit.deepEqual(
			ep.color.rgbToHsb({r:99,g:33,b:66}),
			{h:330,s:67,b:39},
			"ep.color.rgbToHsb({r:99,g:33,b:66})"
		);

		QUnit.equal(
			ep.color.rgbToName({r:0,g:128,b:0}),
			"green",
			"ep.color.rgbToName({r:0,g:128,b:0})"
		);
		QUnit.equal(
			ep.color.rgbToName({r:0,g:0,b:128}),
			"navy",
			"ep.color.rgbToName({r:0,g:0,b:128})"
		);

		QUnit.deepEqual(
			ep.color.hexToRgb('ff7d2c'),
			{r:255,g:125,b:44,a:1},
			"ep.color.rgbToHex('#ff7d2c')"
		);
		QUnit.deepEqual(
			ep.color.hexToRgb('#632142'),
			{r:99,g:33,b:66,a:1},
			"ep.color.rgbToHex('#632142')"
		);
		QUnit.deepEqual(
			ep.color.hexToRgb('#345'),
			{r:51,g:68,b:85,a:1},
			"ep.color.rgbToHex('#345')"
		);
		QUnit.deepEqual(
			ep.color.hexToRgb('#'),
			{r:255,g:255,b:255,a:1},
			"ep.color.rgbToHex('#')"
		);

		QUnit.deepEqual(
			ep.color.hexToHsb('#ff7d2c'),
			{h:23,s:83,b:100},
			"ep.color.hexToHsb('#ff7d2c')"
		);
		QUnit.deepEqual(
			ep.color.hexToHsb('#632142'),
			{h:330,s:67,b:39},
			"ep.color.hexToHsb('#632142')"
		);

		QUnit.equal(
			ep.color.hexToName('#008000'),
			"green",
			"ep.color.hexToName('#008000')"
		);
		QUnit.equal(
			ep.color.hexToName('#000080'),
			"navy",
			"ep.color.hexToName('#000080')"
		);

		QUnit.deepEqual(
			ep.color.hsbToRgb({h:23,s:83,b:100}),
			{r:255,g:124,b:43,a:1},
			"ep.color.hsbToRgb({h:23,s:83,b:100})"
		);
		QUnit.deepEqual(
			ep.color.hsbToRgb({h:330,s:67,b:39}),
			{r:99,g:33,b:66,a:1},
			"ep.color.hsbToRgb({h:330,s:67,b:39})"
		);

		QUnit.equal(
			ep.color.hsbToHex({h:23,s:83,b:100}),
			"ff7c2b",
			"ep.color.hsbToHex({h:23,s:83,b:100})"
		);
		QUnit.equal(
			ep.color.hsbToHex({h:330,s:67,b:39}),
			"632142",
			"ep.color.hsbToHex({h:330,s:67,b:39})"
		);

		QUnit.equal(
			ep.color.hsbToName({h:120,s:100,b:50}),
			"green",
			"ep.color.hsbToName({h:120,s:100,b:50})"
		);
		QUnit.equal(
			ep.color.hsbToName({h:240,s:100,b:50}),
			"navy",
			"ep.color.hsbToName({h:240,s:100,b:50})"
		);

		QUnit.equal(
			ep.color.nameToHex('green'),
			"008000",
			"ep.color.nameToHex('green')"
		);
		QUnit.equal(
			ep.color.nameToHex('navy'),
			"000080",
			"ep.color.nameToHex('navy')"
		);

		QUnit.deepEqual(
			ep.color.nameToRgb('green'),
			{r:0,g:128,b:0,a:1},
			"ep.color.rgbToName('green')"
		);
		QUnit.deepEqual(
			ep.color.nameToRgb('navy'),
			{r:0,g:0,b:128,a:1},
			"ep.color.rgbToName('navy')"
		);

		QUnit.deepEqual(
			ep.color.nameToHsb('green'),
			{h:120,s:100,b:50},
			"ep.color.nameToHsb('green')"
		);
		QUnit.deepEqual(
			ep.color.nameToHsb('navy'),
			{h:240,s:100,b:50},
			"ep.color.nameToHsb('navy')"
		);

		QUnit.equal(
			ep.color.stringToHex('green'),
			"008000",
			"ep.color.stringToHex('green')"
		);
		QUnit.equal(
			ep.color.stringToHex('navy'),
			"000080",
			"ep.color.stringToHex('navy')"
		);
		QUnit.equal(
			ep.color.stringToHex('rgba(120,180,90,0.5)'),
			"78b45a",
			"ep.color.stringToHex('rgba(120,180,90,0.5)')"
		);

		QUnit.deepEqual(
			ep.color.stringToRgb('#008000'),
			{r:0,g:128,b:0,a:1},
			"ep.color.stringToRgb('#008000')"
		);
		QUnit.deepEqual(
			ep.color.stringToRgb('navy'),
			{r:0,g:0,b:128,a:1},
			"ep.color.stringToRgb('navy')"
		);

		QUnit.deepEqual(
			ep.color.stringToHsb('green'),
			{h:120,s:100,b:50},
			"ep.color.stringToHsb('green')"
		);
		QUnit.deepEqual(
			ep.color.stringToHsb('rgb(255,125,44)'),
			{h:23,s:83,b:100},
			"ep.color.stringToHsb('rgb(255,125,44)')"
		);

		QUnit.deepEqual(
			ep.color.stringToName('#008000'),
			'green',
			"ep.color.stringToName('#008000')"
		);
		QUnit.deepEqual(
			ep.color.stringToName('rgb(0,0,128)'),
			'navy',
			"ep.color.stringToName('rgb(0,0,128)')"
		);
		QUnit.deepEqual(
			ep.color.stringToName('rgba(0,128,0,1)'),
			'green',
			"ep.color.stringToName('rgba(0,128,0,1)')"
		);

		QUnit.start();
	});

});

