/*jslint browser: true*/
/*globals define*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/magnifier-test',
    'jquery',

    'ep/ui/magnifier',
    '$ready!'
], function (QUnit, fixture, $, ep) {

    'use strict';

    QUnit.module("ep/ui/magnifier", {
        setup: function () {
            fixture.init();
            $('#qunit-fixture').css({
                position: 'absolute',
                top: '0px',
                left: '0px',
                width: '1000px',
                height: '1000px'
            });
        },
        teardown: fixture.destroy
    });

    QUnit.asyncTest("prototype methods defined", function () {

        QUnit.expect(9);

        $.each(['_create', '_init', '_setOption', '_change', '_resizeZoom', '_enterMag', '_moveMag', '_leaveMag', 'destroy'], function (i, fn) {
            /*jslint unparam: true*/
            QUnit.equal(
                $.isFunction($.ui.uiMagnifier.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );

        });

        QUnit.start();
    });

    QUnit.asyncTest("UI", function () {

        var mag = ep('#mag')
                .uiMagnifier({
                    images: '#images img'
                }),

            mag2 = ep('#mag2')
                .uiMagnifier({
                    action: 'lightbox',
                    images: '#images img',
                    width: 100,
                    height: 100
                }),

            zoom = $('.ep-uiMagnifier-zoom'),

            imgData = ep.ui.imgData('#images img');

        setTimeout(function () {
            QUnit.equal(
                mag2.uiMagnifier('Instance') instanceof $.Widget,
                true,
                "Magnifier widget is created and instance of jQuery.Widget"
            );

            QUnit.equal(
                mag.find('img').length,
                1,
                "ep('#mag img').length"
            );

            QUnit.equal(
                mag.find('img').attr('src'),
                '../ep/ui/magnifier-test-image1_m.jpg',
                "ep('#mag img').attr('src')"
            );

            QUnit.equal(
                zoom.find('img').length,
                2,
                "$('.ep-uiMagnifier-zoom img').length"
            );

            QUnit.equal(
                zoom.find('img').attr('src'),
                '../ep/ui/magnifier-test-image1.jpg',
                "$('.ep-uiMagnifier-zoom img').attr('src')"
            );

            QUnit.equal(
                zoom.width(),
                250,
                "$('.ep-uiMagnifier-zoom').width()"
            );

            QUnit.equal(
                zoom.height(),
                250,
                "$('.ep-uiMagnifier-zoom').height()"
            );

            imgData.current(1);

            setTimeout(function () {

                QUnit.equal(
                    mag.find('img').attr('src'),
                    '../ep/ui/magnifier-test-image2_m.jpg',
                    "ep('#mag img').attr('src')"
                );

                QUnit.equal(
                    zoom.find('img').attr('src'),
                    '../ep/ui/magnifier-test-image2.jpg',
                    "$('.ep-uiMagnifier-zoom img').attr('src')"
                );

                mag.find('.ep-uiMagnifier')
                    .trigger('mouseenter')
                    .trigger({
                        type    : "mousemove",
                        pageX   : 80,
                        pageY   : 330
                    })
                    .trigger({
                        type    : "mousemove",
                        pageX   : 100,
                        pageY   : 330
                    })
                    .trigger({
                        type    : "mousemove",
                        pageX   : 120,
                        pageY   : 330
                    })
                    .trigger({
                        type    : "mousemove",
                        pageX   : 140,
                        pageY   : 330
                    });

                var sel = mag.find('.ep-uiMagnifier-boxSelect');

                QUnit.equal(
                    sel.css('top'),
                    '38px',
                    "ep('#mag .ep-uiMagnifier-boxSelect').css('top')"
                );

                QUnit.equal(
                    sel.css('left'),
                    '38px',
                    "ep('#mag .ep-uiMagnifier-boxSelect').css('left')"
                );

                QUnit.equal(
                    sel.css('width'),
                    '160px',
                    "ep('#mag .ep-uiMagnifier-boxSelect').css('width')"
                );

                QUnit.equal(
                    sel.css('height'),
                    '160px',
                    "ep('#mag .ep-uiMagnifier-boxSelect').css('left')"
                );

                mag.find('.ep-uiMagnifier')
                    .trigger('mouseleave');

                mag2.uiMagnifier('destroy');

                QUnit.equal(
                    mag2.data('uiUiMagnifier'),
                    undefined,
                    "magnifier 2 was destroyed"
                );

                QUnit.start();

            }, 500);

        }, 500);

    });
});